oldir

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 23, 2025 License: ISC Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetContentOfDirectory

func GetContentOfDirectory(name string) (directories []string, files []string, err error)

Retrieves the underlying directories and files of a directory provided by the named path and returning them separately as Slice. The content is sorted by filename

This function does not walk down the path tree and is not returning the content of the subdirectories

If an error occurs while reading the directory or the directory does not exists, than the returning variables are nil and error is not nil and of type PathError.

If a directory is provided that content only has directories or files the corresponding return variable is nil

Types

This section is empty.

Jump to