Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetContentOfDirectory ¶
Retrieves the underlying directories and files of a directory provided by the named path and returning them separately as Slice. The content is sorted by filename
This function does not walk down the path tree and is not returning the content of the subdirectories
If an error occurs while reading the directory or the directory does not exists, than the returning variables are nil and error is not nil and of type PathError.
If a directory is provided that content only has directories or files the corresponding return variable is nil
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.